@@ -8,7 +8,6 @@ import (
 	"runtime"
 	"strings"
 
-	"github.com/lima-vm/lima/pkg/limayaml"
 	"github.com/miekg/dns"
 	"github.com/sirupsen/logrus"
 )
@@ -124,6 +123,7 @@ func NewHandler(opts HandlerOptions) (dns.Handler, error) {
 		{Net: "tcp"},
 	}
 	h := &Handler{
+		truncate:     opts.TruncateReply,
 		clientConfig: cc,
 		clients:      clients,
 		ipv6:         opts.IPv6,
@@ -131,10 +131,11 @@ func NewHandler(opts HandlerOptions) (dns.Handler, error) {
 		hostToIP:     make(map[string]net.IP),
 	}
 	for host, address := range opts.StaticHosts {
+		cname := dns.CanonicalName(host)
 		if ip := net.ParseIP(address); ip != nil {
-			h.hostToIP[host] = ip
+			h.hostToIP[cname] = ip
 		} else {
-			h.cnameToHost[host] = limayaml.Cname(address)
+			h.cnameToHost[cname] = dns.CanonicalName(address)
 		}
 	}
 	return h, nil
@@ -368,7 +369,7 @@ func listenAndServe(network Network, opts ServerOptions) (*dns.Server, error) {
 	var addr string
 	// always enable reply truncate for UDP
 	if network == UDP {
-		opts.TruncateReply = true
+		opts.HandlerOptions.TruncateReply = true
 		addr = fmt.Sprintf("%s:%d", opts.Address, opts.UDPPort)
 	} else {
 		addr = fmt.Sprintf("%s:%d", opts.Address, opts.TCPPort)
