@@ -30,7 +30,7 @@ const (
 )
 
 func defaultContainerdArchives() []File {
-	const nerdctlVersion = "1.0.0"
+	const nerdctlVersion = "1.1.0"
 	location := func(goarch string) string {
 		return "https://github.com/containerd/nerdctl/releases/download/v" + nerdctlVersion + "/nerdctl-full-" + nerdctlVersion + "-linux-" + goarch + ".tar.gz"
 	}
@@ -38,12 +38,12 @@ func defaultContainerdArchives() []File {
 		{
 			Location: location("amd64"),
 			Arch:     X8664,
-			Digest:   "sha256:b7f76a3bf1b8161eb94ebe885945feb2887dfc0d274f9da908a17bc0ef853eb9",
+			Digest:   "sha256:5440c7b3af63df2ad2c98e185e06a27b4a21eea334b05408e84f8502251d9459",
 		},
 		{
 			Location: location("arm64"),
 			Arch:     AARCH64,
-			Digest:   "sha256:e4c9b9434c88847f4d18f8b84c0d073555e4c949546cfa8a21e719de67afdf70",
+			Digest:   "sha256:3b613a1be5a24460c44bb93a3609b790ada94e06efd1a86467d45bec7da8b449",
 		},
 		// No riscv64
 	}
@@ -77,6 +77,13 @@ func MACAddress(uniqueID string) string {
 //   - DNS are picked from the highest priority where DNS is not empty.
 //   - CACertificates Files and Certs are uniquely appended in d, y, o order
 func FillDefault(y, d, o *LimaYAML, filePath string) {
+	if y.VMType == nil {
+		y.VMType = d.VMType
+	}
+	if o.VMType != nil {
+		y.VMType = o.VMType
+	}
+	y.VMType = pointer.String(ResolveVMType(y.VMType))
 	if y.Arch == nil {
 		y.Arch = d.Arch
 	}
@@ -114,22 +121,28 @@ func FillDefault(y, d, o *LimaYAML, filePath string) {
 			}
 		}
 	}
+	var overrideCPUType bool
 	for k, v := range d.CPUType {
 		if len(v) > 0 {
+			overrideCPUType = true
 			cpuType[k] = v
 		}
 	}
 	for k, v := range y.CPUType {
 		if len(v) > 0 {
+			overrideCPUType = true
 			cpuType[k] = v
 		}
 	}
 	for k, v := range o.CPUType {
 		if len(v) > 0 {
+			overrideCPUType = true
 			cpuType[k] = v
 		}
 	}
-	y.CPUType = cpuType
+	if *y.VMType == QEMU || overrideCPUType {
+		y.CPUType = cpuType
+	}
 
 	if y.CPUs == nil {
 		y.CPUs = d.CPUs
@@ -161,13 +174,15 @@ func FillDefault(y, d, o *LimaYAML, filePath string) {
 		y.Disk = pointer.String("100GiB")
 	}
 
+	y.AdditionalDisks = append(append(o.AdditionalDisks, y.AdditionalDisks...), d.AdditionalDisks...)
+
 	if y.Video.Display == nil {
 		y.Video.Display = d.Video.Display
 	}
 	if o.Video.Display != nil {
 		y.Video.Display = o.Video.Display
 	}
-	if y.Video.Display == nil || *y.Video.Display == "" {
+	if (y.Video.Display == nil || *y.Video.Display == "") && *y.VMType == QEMU {
 		y.Video.Display = pointer.String("none")
 	}
 
@@ -300,18 +315,6 @@ func FillDefault(y, d, o *LimaYAML, filePath string) {
 		// After defaults processing the singular HostPort and GuestPort values should not be used again.
 	}
 
-	// If both `useHostResolved` and `HostResolver.Enabled` are defined in the same config,
-	// then the deprecated `useHostResolved` setting is silently ignored.
-	if y.HostResolver.Enabled == nil {
-		y.HostResolver.Enabled = y.UseHostResolver
-	}
-	if d.HostResolver.Enabled == nil {
-		d.HostResolver.Enabled = d.UseHostResolver
-	}
-	if o.HostResolver.Enabled == nil {
-		o.HostResolver.Enabled = o.UseHostResolver
-	}
-
 	if y.HostResolver.Enabled == nil {
 		y.HostResolver.Enabled = d.HostResolver.Enabled
 	}
@@ -342,19 +345,6 @@ func FillDefault(y, d, o *LimaYAML, filePath string) {
 		y.PropagateProxyEnv = pointer.Bool(true)
 	}
 
-	if len(y.Network.VDEDeprecated) > 0 && len(y.Networks) == 0 {
-		for _, vde := range y.Network.VDEDeprecated {
-			network := Network{
-				Interface:            vde.Name,
-				MACAddress:           vde.MACAddress,
-				SwitchPortDeprecated: vde.SwitchPort,
-				VNLDeprecated:        vde.VNL,
-			}
-			y.Networks = append(y.Networks, network)
-		}
-		y.Network.migrated = true
-	}
-
 	networks := make([]Network, 0, len(d.Networks)+len(y.Networks)+len(o.Networks))
 	iface := make(map[string]int)
 	for _, nw := range append(append(d.Networks, y.Networks...), o.Networks...) {
@@ -628,6 +618,25 @@ func NewArch(arch string) Arch {
 	}
 }
 
+func NewVMType(driver string) VMType {
+	switch driver {
+	case "vz":
+		return VZ
+	case "qemu":
+		return QEMU
+	default:
+		logrus.Warnf("Unknown driver: %s", driver)
+		return driver
+	}
+}
+
+func ResolveVMType(s *string) VMType {
+	if s == nil || *s == "" || *s == "default" {
+		return QEMU
+	}
+	return NewVMType(*s)
+}
+
 func ResolveArch(s *string) Arch {
 	if s == nil || *s == "" || *s == "default" {
 		return NewArch(runtime.GOARCH)
