@@ -22,8 +22,6 @@ func TestFillDefault(t *testing.T) {
 	var d, y, o LimaYAML
 
 	opts := []cmp.Option{
-		// Ignore internal NetworkDeprecated.migrated field
-		cmpopts.IgnoreUnexported(NetworkDeprecated{}),
 		// Consider nil slices and empty slices to be identical
 		cmpopts.EquateEmpty(),
 	}
@@ -47,7 +45,8 @@ func TestFillDefault(t *testing.T) {
 
 	// Builtin default values
 	builtin := LimaYAML{
-		Arch: pointer.String(arch),
+		VMType: pointer.String("qemu"),
+		Arch:   pointer.String(arch),
 		CPUType: map[Arch]string{
 			AARCH64: "cortex-a72",
 			X8664:   "qemu64",
@@ -218,7 +217,8 @@ func TestFillDefault(t *testing.T) {
 
 	// Choose values that are different from the "builtin" defaults
 	d = LimaYAML{
-		Arch: pointer.String("unknown"),
+		VMType: pointer.String("vz"),
+		Arch:   pointer.String("unknown"),
 		CPUType: map[Arch]string{
 			AARCH64: "arm64",
 			X8664:   "amd64",
@@ -227,6 +227,9 @@ func TestFillDefault(t *testing.T) {
 		CPUs:   pointer.Int(7),
 		Memory: pointer.String("5GiB"),
 		Disk:   pointer.String("105GiB"),
+		AdditionalDisks: []Disk{
+			"data",
+		},
 		Containerd: Containerd{
 			System: pointer.Bool(true),
 			User:   pointer.Bool(false),
@@ -336,6 +339,7 @@ func TestFillDefault(t *testing.T) {
 
 	y = filledDefaults
 	y.DNS = []net.IP{net.ParseIP("8.8.8.8")}
+	y.AdditionalDisks = []Disk{"overridden"}
 
 	expect = y
 
@@ -343,6 +347,7 @@ func TestFillDefault(t *testing.T) {
 	expect.Probes = append(y.Probes, d.Probes...)
 	expect.PortForwards = append(y.PortForwards, d.PortForwards...)
 	expect.Containerd.Archives = append(y.Containerd.Archives, d.Containerd.Archives...)
+	expect.AdditionalDisks = append(y.AdditionalDisks, d.AdditionalDisks...)
 
 	// Mounts and Networks start with lowest priority first, so higher priority entries can overwrite
 	expect.Mounts = append(d.Mounts, y.Mounts...)
@@ -362,7 +367,8 @@ func TestFillDefault(t *testing.T) {
 	// User-provided overrides should override user-provided config settings
 
 	o = LimaYAML{
-		Arch: pointer.String(arch),
+		VMType: pointer.String("qemu"),
+		Arch:   pointer.String(arch),
 		CPUType: map[Arch]string{
 			AARCH64: "uber-arm",
 			X8664:   "pentium",
@@ -371,6 +377,9 @@ func TestFillDefault(t *testing.T) {
 		CPUs:   pointer.Int(12),
 		Memory: pointer.String("7GiB"),
 		Disk:   pointer.String("117GiB"),
+		AdditionalDisks: []Disk{
+			"test",
+		},
 		Containerd: Containerd{
 			System: pointer.Bool(true),
 			User:   pointer.Bool(false),
@@ -473,6 +482,7 @@ func TestFillDefault(t *testing.T) {
 	expect.Probes = append(append(o.Probes, y.Probes...), d.Probes...)
 	expect.PortForwards = append(append(o.PortForwards, y.PortForwards...), d.PortForwards...)
 	expect.Containerd.Archives = append(append(o.Containerd.Archives, y.Containerd.Archives...), d.Containerd.Archives...)
+	expect.AdditionalDisks = append(append(o.AdditionalDisks, y.AdditionalDisks...), d.AdditionalDisks...)
 
 	expect.HostResolver.Hosts["default"] = d.HostResolver.Hosts["default"]
 	expect.HostResolver.Hosts["MY.Host"] = d.HostResolver.Hosts["host.lima.internal"]
