@@ -7,34 +7,38 @@ import (
 )
 
 type LimaYAML struct {
-	Arch              *Arch             `yaml:"arch,omitempty" json:"arch,omitempty"`
-	Images            []Image           `yaml:"images" json:"images"` // REQUIRED
-	CPUType           map[Arch]string   `yaml:"cpuType,omitempty" json:"cpuType,omitempty"`
-	CPUs              *int              `yaml:"cpus,omitempty" json:"cpus,omitempty"`
-	Memory            *string           `yaml:"memory,omitempty" json:"memory,omitempty"` // go-units.RAMInBytes
-	Disk              *string           `yaml:"disk,omitempty" json:"disk,omitempty"`     // go-units.RAMInBytes
-	Mounts            []Mount           `yaml:"mounts,omitempty" json:"mounts,omitempty"`
-	MountType         *MountType        `yaml:"mountType,omitempty" json:"mountType,omitempty"`
-	SSH               SSH               `yaml:"ssh,omitempty" json:"ssh,omitempty"` // REQUIRED (FIXME)
-	Firmware          Firmware          `yaml:"firmware,omitempty" json:"firmware,omitempty"`
-	Video             Video             `yaml:"video,omitempty" json:"video,omitempty"`
-	Provision         []Provision       `yaml:"provision,omitempty" json:"provision,omitempty"`
-	Containerd        Containerd        `yaml:"containerd,omitempty" json:"containerd,omitempty"`
-	Probes            []Probe           `yaml:"probes,omitempty" json:"probes,omitempty"`
-	PortForwards      []PortForward     `yaml:"portForwards,omitempty" json:"portForwards,omitempty"`
-	Message           string            `yaml:"message,omitempty" json:"message,omitempty"`
-	Networks          []Network         `yaml:"networks,omitempty" json:"networks,omitempty"`
-	Network           NetworkDeprecated `yaml:"network,omitempty" json:"network,omitempty"` // DEPRECATED, use `networks` instead
-	Env               map[string]string `yaml:"env,omitempty" json:"env,omitempty"`
-	DNS               []net.IP          `yaml:"dns,omitempty" json:"dns,omitempty"`
-	HostResolver      HostResolver      `yaml:"hostResolver,omitempty" json:"hostResolver,omitempty"`
-	UseHostResolver   *bool             `yaml:"useHostResolver,omitempty" json:"useHostResolver,omitempty"` // DEPRECATED, use `HostResolver.Enabled` instead
-	PropagateProxyEnv *bool             `yaml:"propagateProxyEnv,omitempty" json:"propagateProxyEnv,omitempty"`
-	CACertificates    CACertificates    `yaml:"caCerts,omitempty" json:"caCerts,omitempty"`
+	VMType          *VMType         `yaml:"vmType,omitempty" json:"vmType,omitempty"`
+	Arch            *Arch           `yaml:"arch,omitempty" json:"arch,omitempty"`
+	Images          []Image         `yaml:"images" json:"images"` // REQUIRED
+	CPUType         map[Arch]string `yaml:"cpuType,omitempty" json:"cpuType,omitempty"`
+	CPUs            *int            `yaml:"cpus,omitempty" json:"cpus,omitempty"`
+	Memory          *string         `yaml:"memory,omitempty" json:"memory,omitempty"` // go-units.RAMInBytes
+	Disk            *string         `yaml:"disk,omitempty" json:"disk,omitempty"`     // go-units.RAMInBytes
+	AdditionalDisks []Disk          `yaml:"additionalDisks,omitempty" json:"additionalDisks,omitempty"`
+	Mounts          []Mount         `yaml:"mounts,omitempty" json:"mounts,omitempty"`
+	MountType       *MountType      `yaml:"mountType,omitempty" json:"mountType,omitempty"`
+	SSH             SSH             `yaml:"ssh,omitempty" json:"ssh,omitempty"` // REQUIRED (FIXME)
+	Firmware        Firmware        `yaml:"firmware,omitempty" json:"firmware,omitempty"`
+	Video           Video           `yaml:"video,omitempty" json:"video,omitempty"`
+	Provision       []Provision     `yaml:"provision,omitempty" json:"provision,omitempty"`
+	Containerd      Containerd      `yaml:"containerd,omitempty" json:"containerd,omitempty"`
+	Probes          []Probe         `yaml:"probes,omitempty" json:"probes,omitempty"`
+	PortForwards    []PortForward   `yaml:"portForwards,omitempty" json:"portForwards,omitempty"`
+	Message         string          `yaml:"message,omitempty" json:"message,omitempty"`
+	Networks        []Network       `yaml:"networks,omitempty" json:"networks,omitempty"`
+	// `network` was deprecated in Lima v0.7.0, removed in Lima v0.14.0. Use `networks` instead.
+	Env          map[string]string `yaml:"env,omitempty" json:"env,omitempty"`
+	DNS          []net.IP          `yaml:"dns,omitempty" json:"dns,omitempty"`
+	HostResolver HostResolver      `yaml:"hostResolver,omitempty" json:"hostResolver,omitempty"`
+	// `useHostResolver` was deprecated in Lima v0.8.1, removed in Lima v0.14.0. Use `hostResolver.enabled` instead.
+	PropagateProxyEnv *bool          `yaml:"propagateProxyEnv,omitempty" json:"propagateProxyEnv,omitempty"`
+	CACertificates    CACertificates `yaml:"caCerts,omitempty" json:"caCerts,omitempty"`
+	Rosetta           Rosetta        `yaml:"rosetta,omitempty" json:"rosetta,omitempty"`
 }
 
 type Arch = string
 type MountType = string
+type VMType = string
 
 const (
 	X8664   Arch = "x86_64"
@@ -43,8 +47,17 @@ const (
 
 	REVSSHFS MountType = "reverse-sshfs"
 	NINEP    MountType = "9p"
+	VIRTIOFS MountType = "virtiofs"
+
+	QEMU VMType = "qemu"
+	VZ   VMType = "vz"
 )
 
+type Rosetta struct {
+	Enabled bool `yaml:"enabled" json:"enabled"`
+	BinFmt  bool `yaml:"binfmt" json:"binfmt"`
+}
+
 type File struct {
 	Location string        `yaml:"location" json:"location"` // REQUIRED
 	Arch     Arch          `yaml:"arch,omitempty" json:"arch,omitempty"`
@@ -62,6 +75,8 @@ type Image struct {
 	Initrd *File   `yaml:"initrd,omitempty" json:"initrd,omitempty"`
 }
 
+type Disk = string
+
 type Mount struct {
 	Location   string `yaml:"location" json:"location"` // REQUIRED
 	MountPoint string `yaml:"mountPoint,omitempty" json:"mountPoint,omitempty"`
@@ -169,6 +184,9 @@ type Network struct {
 	Lima string `yaml:"lima,omitempty" json:"lima,omitempty"`
 	// Socket is a QEMU-compatible socket
 	Socket string `yaml:"socket,omitempty" json:"socket,omitempty"`
+	// VZNAT uses VZNATNetworkDeviceAttachment. Needs VZ. No root privilege is required.
+	VZNAT *bool `yaml:"vzNAT,omitempty" json:"vzNAT,omitempty"`
+
 	// VNLDeprecated is a Virtual Network Locator (https://github.com/rd235/vdeplug4/commit/089984200f447abb0e825eb45548b781ba1ebccd).
 	// On macOS, only VDE2-compatible form (optionally with vde:// prefix) is supported.
 	// VNLDeprecated is deprecated. Use Socket.
@@ -195,12 +213,6 @@ type CACertificates struct {
 // Types have been renamed to turn all references to the old names into compiler errors,
 // and to avoid accidental usage in new code.
 
-type NetworkDeprecated struct {
-	VDEDeprecated []VDEDeprecated `yaml:"vde,omitempty" json:"vde,omitempty"`
-	// migrate will be true when `network.VDE` has been copied to `networks` by FillDefaults()
-	migrated bool
-}
-
 type VDEDeprecated struct {
 	VNL        string `yaml:"vnl,omitempty" json:"vnl,omitempty"`
 	SwitchPort uint16 `yaml:"switchPort,omitempty" json:"switchPort,omitempty"` // VDE Switch port, not TCP/UDP port
