@@ -15,7 +15,6 @@ import (
 	"github.com/lima-vm/lima/pkg/localpathutil"
 	"github.com/lima-vm/lima/pkg/networks"
 	"github.com/lima-vm/lima/pkg/osutil"
-	qemu "github.com/lima-vm/lima/pkg/qemu/const"
 	"github.com/sirupsen/logrus"
 )
 
@@ -144,9 +143,9 @@ func Validate(y LimaYAML, warn bool) error {
 	}
 
 	switch *y.MountType {
-	case REVSSHFS, NINEP:
+	case REVSSHFS, NINEP, VIRTIOFS:
 	default:
-		return fmt.Errorf("field `mountType` must be %q or %q , got %q", REVSSHFS, NINEP, *y.MountType)
+		return fmt.Errorf("field `mountType` must be %q or %q or %q, got %q", REVSSHFS, NINEP, VIRTIOFS, *y.MountType)
 	}
 
 	// y.Firmware.LegacyBIOS is ignored for aarch64, but not a fatal error.
@@ -262,15 +261,6 @@ func Validate(y LimaYAML, warn bool) error {
 }
 
 func validateNetwork(y LimaYAML, warn bool) error {
-	if len(y.Network.VDEDeprecated) > 0 {
-		if y.Network.migrated {
-			if warn {
-				logrus.Warnf("field `network.VDE` is deprecated; please use `networks` instead")
-			}
-		} else {
-			return fmt.Errorf("you cannot use deprecated field `network.VDE` together with replacement field `networks`")
-		}
-	}
 	interfaceName := make(map[string]int)
 	for i, nw := range y.Networks {
 		field := fmt.Sprintf("networks[%d]", i)
@@ -281,6 +271,9 @@ func validateNetwork(y LimaYAML, warn bool) error {
 			if nw.Socket != "" {
 				return fmt.Errorf("field `%s.lima` and field `%s.socket` are mutually exclusive", field, field)
 			}
+			if nw.VZNAT != nil && *nw.VZNAT {
+				return fmt.Errorf("field `%s.lima` and field `%s.vzNAT` are mutually exclusive", field, field)
+			}
 			if nw.VNLDeprecated != "" {
 				return fmt.Errorf("field `%s.lima` and field `%s.vnl` are mutually exclusive", field, field)
 			}
@@ -295,6 +288,9 @@ func validateNetwork(y LimaYAML, warn bool) error {
 				return fmt.Errorf("field `%s.lima` references network %q which is not defined in networks.yaml", field, nw.Lima)
 			}
 		} else if nw.Socket != "" {
+			if nw.VZNAT != nil && *nw.VZNAT {
+				return fmt.Errorf("field `%s.socket` and field `%s.vzNAT` are mutually exclusive", field, field)
+			}
 			if nw.VNLDeprecated != "" {
 				return fmt.Errorf("field `%s.socket` and field `%s.vnl` are mutually exclusive", field, field)
 			}
@@ -306,6 +302,22 @@ func validateNetwork(y LimaYAML, warn bool) error {
 			} else if err == nil && fi.Mode()&os.ModeSocket == 0 {
 				return fmt.Errorf("field `%s.socket` %q points to a non-socket file", field, nw.Socket)
 			}
+		} else if nw.VZNAT != nil && *nw.VZNAT {
+			if y.VMType == nil || *y.VMType != VZ {
+				return fmt.Errorf("field `%s.vzNAT` requires `vmType` to be %q", field, VZ)
+			}
+			if nw.Lima != "" {
+				return fmt.Errorf("field `%s.vzNAT` and field `%s.lima` are mutually exclusive", field, field)
+			}
+			if nw.Socket != "" {
+				return fmt.Errorf("field `%s.vzNAT` and field `%s.socket` are mutually exclusive", field, field)
+			}
+			if nw.VNLDeprecated != "" {
+				return fmt.Errorf("field `%s.vzNAT` and field `%s.vnl` are mutually exclusive", field, field)
+			}
+			if nw.SwitchPortDeprecated != 0 {
+				return fmt.Errorf("field `%s.switchPort` cannot be used with field `%s.vzNAT`", field, field)
+			}
 		} else {
 			if nw.VNLDeprecated == "" {
 				return fmt.Errorf("field `%s.lima`, field `%s.socket`, or field `%s.vnl` must be set", field, field, field)
@@ -365,8 +377,8 @@ func validateNetwork(y LimaYAML, warn bool) error {
 		if strings.ContainsAny(nw.Interface, " \t\n/") {
 			return fmt.Errorf("field `%s.interface` must not contain whitespace or slashes", field)
 		}
-		if nw.Interface == qemu.SlirpNICName {
-			return fmt.Errorf("field `%s.interface` must not be set to %q because it is reserved for slirp", field, qemu.SlirpNICName)
+		if nw.Interface == networks.SlirpNICName {
+			return fmt.Errorf("field `%s.interface` must not be set to %q because it is reserved for slirp", field, networks.SlirpNICName)
 		}
 		if prev, ok := interfaceName[nw.Interface]; ok {
 			return fmt.Errorf("field `%s.interface` value %q has already been used by field `networks[%d].interface`", field, nw.Interface, prev)
