@@ -12,27 +12,20 @@ import (
 	"text/template"
 	"time"
 
+	"github.com/lima-vm/lima/pkg/driver"
+	"github.com/lima-vm/lima/pkg/driverutil"
+
 	"github.com/lima-vm/lima/pkg/downloader"
 	hostagentevents "github.com/lima-vm/lima/pkg/hostagent/events"
 	"github.com/lima-vm/lima/pkg/limayaml"
-	"github.com/lima-vm/lima/pkg/qemu"
 	"github.com/lima-vm/lima/pkg/store"
 	"github.com/lima-vm/lima/pkg/store/filenames"
 	"github.com/sirupsen/logrus"
 )
 
-func ensureDisk(ctx context.Context, instName, instDir string, y *limayaml.LimaYAML) error {
-	qCfg := qemu.Config{
-		Name:        instName,
-		InstanceDir: instDir,
-		LimaYAML:    y,
-	}
-	if err := qemu.EnsureDisk(qCfg); err != nil {
-		return err
-	}
-
-	return nil
-}
+// DefaultWatchHostAgentEventsTimeout is the duration to wait for the instance
+// to be running before timing out.
+const DefaultWatchHostAgentEventsTimeout = 10 * time.Minute
 
 // ensureNerdctlArchiveCache prefetches the nerdctl-full-VERSION-linux-GOARCH.tar.gz archive
 // into the cache before launching the hostagent process, so that we can show the progress in tty.
@@ -90,7 +83,16 @@ func Start(ctx context.Context, inst *store.Instance) error {
 		return err
 	}
 
-	if err := ensureDisk(ctx, inst.Name, inst.Dir, y); err != nil {
+	limaDriver := driverutil.CreateTargetDriverInstance(&driver.BaseDriver{
+		Instance: inst,
+		Yaml:     y,
+	})
+
+	if err := limaDriver.Validate(); err != nil {
+		return err
+	}
+
+	if err := limaDriver.CreateDisk(); err != nil {
 		return err
 	}
 	nerdctlArchiveCache, err := ensureNerdctlArchiveCache(y)
@@ -170,7 +172,7 @@ func Start(ctx context.Context, inst *store.Instance) error {
 	}
 }
 
-func waitHostAgentStart(ctx context.Context, haPIDPath, haStderrPath string) error {
+func waitHostAgentStart(_ context.Context, haPIDPath, haStderrPath string) error {
 	begin := time.Now()
 	deadlineDuration := 5 * time.Second
 	deadline := begin.Add(deadlineDuration)
@@ -185,7 +187,7 @@ func waitHostAgentStart(ctx context.Context, haPIDPath, haStderrPath string) err
 }
 
 func watchHostAgentEvents(ctx context.Context, inst *store.Instance, haStdoutPath, haStderrPath string, begin time.Time) error {
-	ctx2, cancel := context.WithTimeout(ctx, 10*time.Minute)
+	ctx, cancel := context.WithTimeout(ctx, watchHostAgentTimeout(ctx))
 	defer cancel()
 
 	var (
@@ -221,7 +223,7 @@ func watchHostAgentEvents(ctx context.Context, inst *store.Instance, haStdoutPat
 		return false
 	}
 
-	if xerr := hostagentevents.Watch(ctx2, haStdoutPath, haStderrPath, begin, onEvent); xerr != nil {
+	if xerr := hostagentevents.Watch(ctx, haStdoutPath, haStderrPath, begin, onEvent); xerr != nil {
 		return xerr
 	}
 
@@ -236,6 +238,23 @@ func watchHostAgentEvents(ctx context.Context, inst *store.Instance, haStdoutPat
 	return nil
 }
 
+type watchHostAgentEventsTimeoutKey = struct{}
+
+// WithWatchHostAgentEventsTimeout sets the value of the timeout to use for
+// watchHostAgentEvents in the given Context.
+func WithWatchHostAgentTimeout(ctx context.Context, timeout time.Duration) context.Context {
+	return context.WithValue(ctx, watchHostAgentEventsTimeoutKey{}, timeout)
+}
+
+// watchHostAgentEventsTimeout returns the value of the timeout to use for
+// watchHostAgentEvents contained in the given Context, or its default value.
+func watchHostAgentTimeout(ctx context.Context) time.Duration {
+	if timeout, ok := ctx.Value(watchHostAgentEventsTimeoutKey{}).(time.Duration); ok {
+		return timeout
+	}
+	return DefaultWatchHostAgentEventsTimeout
+}
+
 func LimactlShellCmd(instName string) string {
 	shellCmd := fmt.Sprintf("limactl shell %s", instName)
 	if instName == "default" {
