@@ -10,6 +10,7 @@ const (
 	ConfigDir   = "_config"
 	CacheDir    = "_cache"    // not yet implemented
 	NetworksDir = "_networks" // network log files are stored here
+	DisksDir    = "_disks"    // disks are stored here
 )
 
 // Filenames used inside the ConfigDir
@@ -32,7 +33,6 @@ const (
 	Kernel             = "kernel"
 	KernelCmdline      = "kernel.cmdline"
 	Initrd             = "initrd"
-	QemuPID            = "qemu.pid"
 	QMPSock            = "qmp.sock"
 	SerialLog          = "serial.log"
 	SerialSock         = "serial.sock"
@@ -42,11 +42,20 @@ const (
 	HostAgentSock      = "ha.sock"
 	HostAgentStdoutLog = "ha.stdout.log"
 	HostAgentStderrLog = "ha.stderr.log"
+	VzIdentifier       = "vz-identifier"
+	VzEfi              = "vz-efi"
 
 	// SocketDir is the default location for forwarded sockets with a relative paths in HostSocket
 	SocketDir = "sock"
 )
 
+// Filenames used under a disk directory
+
+const (
+	DataDisk = "datadisk"
+	InUseBy  = "in_use_by"
+)
+
 // LongestSock is the longest socket name.
 // On macOS, the full path of the socket (excluding the NUL terminator) must be less than 104 characters.
 // See unix(4).
@@ -56,3 +65,7 @@ const (
 // ssh appends 16 bytes of random characters when it first creates the socket:
 // https://github.com/openssh/openssh-portable/blob/V_8_7_P1/mux.c#L1271-L1285
 const LongestSock = SSHSock + ".1234567890123456"
+
+func PIDFile(name string) string {
+	return name + ".pid"
+}
